.. _install:

=====================
2. Install the plugin
=====================

Here we will simply install the plugin before continuing.

.. include:: ../../../README.rst
   :start-after: Start installation description
   :end-before: End installation description

.. _AiiDA-VASP: https://github.com/aiida-vasp/aiida-vasp
.. _AiiDA: https://www.aiida.net
.. _AiiDA prerequisites: https://aiida-core.readthedocs.io/en/latest/install/prerequisites.html
